@@ -326,6 +326,28 @@ repos_update_views <- function(repos = ".",
 	     "<body>",
              paste0("<h1>", reposname, " Task Views</h1>"),
 	     "",
+	     sprintf("<p>%s task views aim to provide some guidance which packages on %s", reposname, reposname),
+	     "are relevant for tasks related to a certain topic. They give a brief overview of the included packages",
+	     "and can be automatically installed using the <a href=\"https://CRAN.R-project.org/package=ctv\">ctv</a>",
+	     "package. The views are intended to have a sharp focus so that it is sufficiently",
+	     "clear which packages should be included (or excluded) - and they are <em>not</em> meant",
+	     "to endorse the \"best\" packages for a given task.</p>",
+	     "",
+	     "<ul>",
+             "  <li>To automatically install the views, the <a href=\"https://CRAN.R-project.org/package=ctv\">ctv</a> package needs to be installed, e.g., via<br />",
+	     "   <tt>install.packages(\"ctv\")</tt><br />",
+	     "   and then the views can be installed via <tt>install.views</tt> or <tt>update.views</tt>",	     
+	     "   (where the latter only installs those packages are not installed and up-to-date), e.g.,<br />",
+	     "   <tt>ctv::install.views(\"Econometrics\")</tt><br />",
+	     "   <tt>ctv::update.views(\"Econometrics\")</tt></li>",
+	     "  <li>The task views are maintained by volunteers. You can help them by suggesting packages",
+	     "    that should be included in their task views. The contact e-mail addresses are listed on",
+	     "    the individual task view pages.</li>",
+	     "  <li>For general concerns regarding task views contact the <a href=\"https://CRAN.R-project.org/package=ctv\">ctv</a> package maintainer.</li>",
+	     "</ul>",
+	     "",
+	     "<h3>Topics</h3>",
+	     "",
              paste0("<table summary=\"", reposname," Task Views\">"),
 	     apply(idx, 1, function(x) {
                  paste0("  <tr valign=\"top\">\n    <td><a href=\"",
@@ -334,15 +356,6 @@ repos_update_views <- function(repos = ".",
              }),
 	     "</table>",
 	     "",
-             "<p>To automatically install these views, the ctv package needs to be installed, e.g., via<br />",
-	     "   <tt>install.packages(\"ctv\")</tt><br />",
-	     "   <tt>library(\"ctv\")</tt><br />",
-	     "   and then the views can be installed via <tt>install.views</tt> or <tt>update.views</tt>",	     
-	     "   (which first assesses which of the packages are already installed and up-to-date), e.g.,<br />",
-	     "   <tt>install.views(\"Econometrics\")</tt><br />",
-	     "   or<br />",
-	     "   <tt>update.views(\"Econometrics\")</tt></p>",
-	     "",
 	     "</body>",
 	     "</html>")
     writeLines(idx, con = index)
